this is library nade for besuto and made by besuto

UPDATE LOG
------------------------------------------------------------------------------
besuto 0.0.1 unfinished release to learn Pypi upload machanic

besuto 0.0.2 realease the image Augmentation function (for my school project) and face extracttion which use pretrain model in mtcnn library

besuto 0.0.3 realease the pipeline for training all VggFace model from the paper
https://www.robots.ox.ac.uk/~vgg/publications/2015/Parkhi15/parkhi15.pdf
https://www.robots.ox.ac.uk/~vgg/publications/2018/Cao18/cao18.pdf

besuto 0.0.4 fix bug that keras_application is not found

besuto 0.0.5    - fix corrupted ui in load_face_dataset function
                - fix functional type error in trains function
                